@@ -1,3 +1,112 @@
+"""
+Most of the collection objects that are returned from function
+invocations in the okcupyd library are instances of
+:class:`~okcupyd.util.fetchable.Fetchable`. In most cases, it is fine
+to treat these objects as though they are lists because they can be iterated
+over, sliced and accessed by index, just like lists:
+
+.. code:: python
+
+   for question in user.profile.questions:
+       print(question.answer.text)
+
+   a_random_question = user.profile.questions[2]
+   for question in questions[2:4]:
+       print(question.answer_options[0])
+
+However, in some cases, it is important to be aware of the subtle
+differences between :class:`~okcupyd.util.fetchable.Fetchable` objects
+and python lists.
+:class:`~okcupyd.util.fetchable.Fetchable` construct the elements that
+they "contain" lazily. In most of its uses in the okcupyd library,
+this means that http requests can be made to populate
+:class:`~okcupyd.util.fetchable.Fetchable` instances as its elments
+are requested.
+
+The :attr:`~okcupyd.profile.Profile.questions`
+:class:`~okcupyd.util.fetchable.Fetchable` that is used in the example
+above fetches the pages that are used to construct its contents in
+batches of 10 questions. This means that the actual call to retrieve
+data is made when iteration starts. If you enable the request logger
+when you run this code snippet, you get output that illustrates this
+fact:
+
+.. code::
+
+   2014-10-29 04:25:04 Livien-MacbookAir requests.packages.urllib3.connectionpool[82461] DEBUG "GET /profile/ShrewdDrew/questions?leanmode=1&low=11 HTTP/1.1" 200 None
+    Yes
+    Yes
+    Kiss someone.
+    Yes.
+    Yes
+    Sex.
+    Both equally
+    No, I wouldn't give it as a gift.
+    Maybe, I want to know all the important stuff.
+    Once or twice a week
+    2014-10-29 04:25:04 Livien-MacbookAir requests.packages.urllib3.connectionpool[82461] DEBUG "GET /profile/ShrewdDrew/questions?leanmode=1&low=21 HTTP/1.1" 200 None
+    No.
+    No
+    No
+    Yes
+    Rarely / never
+    Always.
+    Discovering your shared interests
+    The sun
+    Acceptable.
+    No.
+
+Some fetchables will continue fetching content for quite a long time.
+The search fetchable, for example, will fetch content until okcupid runs
+out of search results. As such, things like:
+
+.. code:: python
+
+    for profile in user.search():
+        profile.message("hey!")
+
+should be avoided, as they are likely to generate a massive number of requests
+to okcupid.com.
+
+
+Another subtlety of the :class:`~okcupyd.util.fetchable.Fetchable`
+class is that its instances cache its contained results. This means that
+the second iteration over :attr:`okcupyd.profile.Profile.questions` in the
+example below does not result in any http requests:
+
+.. code:: python
+
+    for question in user.profile.questions:
+        print(question.text)
+
+    for question in user.profile.questions:
+        print(question.answer)
+
+It is important to understand that this means that the contents of a
+:class:`~okcupyd.util.fetchable.Fetchable` are not guarenteed to be in
+sync with okcupid.com the second time they are requested. Calling
+:meth:`~okcupyd.util.fetchable.Fetchable.refresh` will cause the
+:class:`~okcupyd.util.fetchable.Fetchable` to request new data from
+okcupid.com when its contents are requested. The code snippet that
+follows prints out all the questions that the logged in user has
+answered roughly once per hour, including ones that are answered while
+the program is running.
+
+
+.. code:: python
+
+    import time
+
+    while True:
+        for question in user.profile.questions:
+            print(question.text)
+        user.profile.questions.refresh()
+        time.sleep(3600)
+
+Without the call to  `user.profile.questions.refresh()`, this program
+would never update the user.profile.questions instance, and thus what
+would be printed to the screen with each iteration of the for loop.
+"""
 import itertools
 from lxml import html
 
@@ -195,6 +304,7 @@ class SimpleProcessor(object):
     def process(self, text_response):
         if not text_response.strip():
             yield StopIteration
+            
             raise StopIteration()
         for element in self._element_xpath.apply_(
             html.fromstring(text_response)
