@@ -7,33 +7,33 @@ import pytest
 from okcupyd import util
 
 
-@util.n_partialable
+@util.curry
 def crazy(a, self):
     return a + self.starter
 
 
-class HasPartialableMethods(object):
+class HasCurryMethods(object):
 
     def __init__(self, starter):
         self.starter = starter
         self.on_instance = crazy
 
-    @util.n_partialable
-    def partialable(self, x, y=0):
+    @util.curry
+    def curry(self, x, y=0):
         return self.starter * x * y
 
     on_class = crazy(1)
 
 
-def test_partialable_method_behavior():
-    assert HasPartialableMethods(2).partialable(y=2)(1) == 4
-    hpm = HasPartialableMethods(2)
+def test_curry_method_behavior():
+    assert HasCurryMethods(2).curry(y=2)(1) == 4
+    hpm = HasCurryMethods(2)
     assert hpm.on_instance(2, hpm) == 4
     assert hpm.on_class() == 3
 
 
-def test_partialable_with_kwargs_taking_function():
-    @util.n_partialable
+def test_curry_with_kwargs_taking_function():
+    @util.curry
     def kwarg_taking_function(arg, **kwargs):
         kwargs['k'] = arg
         return kwargs
@@ -69,7 +69,7 @@ def test_get_cached_properties():
 
 def test_overwrite_kwarg():
 
-    @util.n_partialable
+    @util.curry
     def test(k, a=0, b=0):
         return k + a + b
 
@@ -153,3 +153,14 @@ def test_bool_on_fetchable():
 
     assert fetchable
 
+
+def test_curry_on_classmethod():
+    class TestClass(object):
+
+        @classmethod
+        @util.curry
+        def test(cls, arg, optional=3):
+            return optional + arg
+
+    assert TestClass.test(optional=1)(2) == 3
+    assert TestClass().test(optional=3)(2) == 5
